# WARNING: This package is synchronized with Fedora!

# Prevent having to backport tons of dependencies for older Mageia releases
%if 0%{?mageia} >= 6
%bcond_without python3
%else
%bcond_with python3
%endif

%if %{with python3}
%global python_sitelib %{python3_sitelib}
%global __python %{__python3}
%else
%global python_sitelib %{python2_sitelib}
%global __python %{__python2}
%endif

# mock group id allocate from Fedora
%global mockgid 135

# Fedora release numbers are part of upstream releases
%global origrel 1

Summary: Builds packages inside chroots
Name: mock
Group: Development/Other
Version: 1.4.2
Release: %mkrel 1
License: GPLv2+
URL: https://github.com/rpm-software-management/mock/
Source: %{url}/archive/%{name}-%{version}-%{origrel}.tar.gz

# Mageia specific patches
# Mageia doesn't yet have the C.UTF-8 locale in glibc/locales,
# so we need to fall back to the C locale instead.
Patch1000: mock-1.4.2-Revert-use-LC_ALL-C.UTF-8-rather-than-plain-C.patch

BuildArch: noarch
%if 0%{?mageia} >= 6
Requires: yum >= 3.4.3-14
%else
Requires: yum >= 2.4
%endif
Requires: tar
Requires: pigz
Requires: usermode-consoleonly
%if 0%{?mageia} >= 6
Requires: yum-utils >= 1.1.31-5
%else
Requires: yum-utils
%endif
Requires: createrepo_c

Requires: distribution-gpg-keys >= 1.10

# Install extra configs by default
Recommends: mock-mageia-configs

%if ! %{with python3}
Requires: pyliblzma
%endif

Requires: systemd

Requires(pre): shadow-utils
Requires(post): coreutils, sed

# We need /etc/os-release
Requires(post): system-release

BuildRequires: autoconf, automake
BuildRequires: bash-completion

%if %{with python3}
Requires: python3
Requires: python3-distro
Requires: python3-six >= 1.4.0
Requires: python3-requests
Requires: python3-rpm
BuildRequires: python3-devel
#check
BuildRequires: python3-pylint
BuildRequires: python3-requests
BuildRequires: python3-distro
BuildRequires: python3-six >= 1.4.0
BuildRequires: python3-rpm
%else
Requires: python-ctypes
Requires: python2-distro
Requires: python-six >= 1.4.0
Requires: python-requests
Requires: python >= 2.6
Requires: python-rpm
%endif
# BR to ensure bytecompile (rhbz#1411588)
BuildRequires: python-devel

# We need these for the Mageia targets
Requires: dnf
Requires: dnf-plugins-core

Recommends: btrfs-progs
BuildRequires: perl

# hwinfo plugin
Requires: util-linux
Requires: coreutils
Requires: procps-ng 

%description
Mock takes an SRPM and builds it in a chroot.

%package scm
Summary: Mock SCM integration module
Group: Development/Other
Requires: %{name} = %{version}-%{release}
Requires: cvs
Requires: git
Requires: subversion
Requires: tar

%description scm
Mock SCM integration module.

%package lvm
Summary: LVM plugin for mock
Group: Development/Other
Requires: %{name} = %{version}-%{release}
Requires: lvm2

%description lvm
Mock plugin that enables using LVM as a backend and support creating snapshots
of the buildroot.

%prep
%autosetup -n %{name}-%{name}-%{version}-%{origrel} -p1

for file in py/mock.py py/mockchain.py; do
  sed -i 1"s|#!/usr/bin/python |#!%{__python} |" $file
done

%build
for i in py/mock.py py/mockchain.py; do
    perl -p -i -e 's|^__VERSION__\s*=.*|__VERSION__="%{version}"|' $i
    perl -p -i -e 's|^SYSCONFDIR\s*=.*|SYSCONFDIR="%{_sysconfdir}"|' $i
    perl -p -i -e 's|^PYTHONDIR\s*=.*|PYTHONDIR="%{python_sitelib}"|' $i
    perl -p -i -e 's|^PKGPYTHONDIR\s*=.*|PKGPYTHONDIR="%{python_sitelib}/mockbuild"|' $i
done
for i in docs/mockchain.1 docs/mock.1; do
    perl -p -i -e 's|@VERSION@|%{version}|' $i
done


%install
install -d %{buildroot}%{_bindir}
install -d %{buildroot}%{_libexecdir}/mock
install py/mockchain.py %{buildroot}%{_bindir}/mockchain
install py/mock.py %{buildroot}%{_libexecdir}/mock/mock
ln -s consolehelper %{buildroot}%{_bindir}/mock

install -d %{buildroot}%{_sysconfdir}/pam.d
cp -a etc/pam/* %{buildroot}%{_sysconfdir}/pam.d/

install -d %{buildroot}%{_sysconfdir}/mock
cp -a etc/mock/* %{buildroot}%{_sysconfdir}/mock/

install -d %{buildroot}%{_sysconfdir}/security/console.apps/
cp -a etc/consolehelper/mock %{buildroot}%{_sysconfdir}/security/console.apps/%{name}

install -d %{buildroot}%{_datadir}/bash-completion/completions/
cp -a etc/bash_completion.d/* %{buildroot}%{_datadir}/bash-completion/completions/
ln -s mock %{buildroot}%{_datadir}/bash-completion/completions/mockchain

install -d %{buildroot}%{_sysconfdir}/pki/mock
cp -a etc/pki/* %{buildroot}%{_sysconfdir}/pki/mock/

install -d %{buildroot}%{python_sitelib}/
cp -a py/mockbuild %{buildroot}%{python_sitelib}/

install -d %{buildroot}%{_mandir}/man1
cp -a docs/mockchain.1 docs/mock.1 %{buildroot}%{_mandir}/man1/

install -d %{buildroot}/var/lib/mock
install -d %{buildroot}/var/cache/mock

# generate files section with config - there is many of them
echo "%defattr(0644, root, mock)" > %{name}.cfgs
find %{buildroot}%{_sysconfdir}/mock -name "*.cfg" \
    | sed -e "s|^%{buildroot}|%%config(noreplace) |" >> %{name}.cfgs

# just for %%ghosting purposes
ln -s mageia-cauldron-x86_64.cfg %{buildroot}%{_sysconfdir}/mock/default.cfg

if [ -d %{buildroot}%{_datadir}/bash-completion ]; then
    echo %{_datadir}/bash-completion/completions/mock >> %{name}.cfgs
    echo %{_datadir}/bash-completion/completions/mockchain >> %{name}.cfgs
elif [ -d %{buildroot}%{_sysconfdir}/bash_completion.d ]; then
    echo %{_sysconfdir}/bash_completion.d/mock >> %{name}.cfgs
fi

%pre

# check for existence of mock group, create it if not found
getent group mock > /dev/null || groupadd -f -g %mockgid -r mock
exit 0

%post

# fix cache permissions from old installs
chmod 2775 %{_localstatedir}/cache/%{name}

if [ -s /etc/os-release ]; then
    if [ -s /etc/mageia-release ]; then
        if grep -Fiq Cauldron /etc/mageia-release; then
             ver=cauldron
        else
             ver=$(source /etc/os-release && echo $VERSION_ID | cut -d. -f1 | grep -o '[0-9]\+')
        fi
    fi
fi

# Read the distro arch from /etc/mageia-release
mock_arch=$(sed -n '/^$/!{$ s/.* \(\w*\)$/\1/p}' /etc/mageia-release)

cfg=mageia-$ver-${mock_arch}.cfg

if [ -e %{_sysconfdir}/%{name}/$cfg ]; then
   if [ "$(readlink %{_sysconfdir}/%{name}/default.cfg)" != "$cfg" ]; then
      ln -s $cfg %{_sysconfdir}/%{name}/default.cfg 2>/dev/null || ln -s -f $cfg %{_sysconfdir}/%{name}/default.cfg.rpmnew
   fi
else
   echo "Warning: file %{_sysconfdir}/%{name}/$cfg does not exist."
   echo "         unable to update %{_sysconfdir}/%{name}/default.cfg"
fi
:

%if %{with python3}
%check
# ignore the errors for now, just print them and hopefully somebody will fix it one day
python3-pylint py/mockbuild/ py/*.py py/mockbuild/plugins/* || :

%endif

%files -f %{name}.cfgs
%defattr(-, root, root)

# executables
%{_bindir}/mock
%{_bindir}/mockchain
%{_libexecdir}/mock

# python stuff
%{python_sitelib}/*
%exclude %{python_sitelib}/mockbuild/scm.*
%if %{with python3}
%exclude %{python3_sitelib}/mockbuild/__pycache__/scm.*.py*
%endif
%exclude %{python_sitelib}/mockbuild/plugins/lvm_root.*
%if %{with python3}
%exclude %{python3_sitelib}/mockbuild/plugins/__pycache__/lvm_root.*.py*
%endif
# config files
%dir  %{_sysconfdir}/%{name}
%ghost %config(noreplace,missingok) %{_sysconfdir}/%{name}/default.cfg
%config(noreplace) %{_sysconfdir}/%{name}/*.ini
%config(noreplace) %{_sysconfdir}/pam.d/%{name}
%config(noreplace) %{_sysconfdir}/security/console.apps/%{name}

# directory for personal gpg keys
%dir %{_sysconfdir}/pki/mock
%config(noreplace) %{_sysconfdir}/pki/mock/*

# docs
%{_mandir}/man1/mock.1.*
%{_mandir}/man1/mockchain.1.*

# license
%license COPYING

# cache & build dirs
%defattr(0775, root, mock, 02775)
%dir %{_localstatedir}/cache/mock
%dir %{_localstatedir}/lib/mock

%files scm
%{python_sitelib}/mockbuild/scm.py*
%if %{with python3}
%{python3_sitelib}/mockbuild/__pycache__/scm.*.py*
%endif

%files lvm
%{python_sitelib}/mockbuild/plugins/lvm_root.*
%if %{with python3}
%{python3_sitelib}/mockbuild/plugins/__pycache__/lvm_root.*.py*
%endif


%changelog
* Sat Jun 10 2017 ngompa <ngompa> 1.4.2-1.mga6
+ Revision: 1107507
- Add patch to switch from C.UTF-8 to C, since C.UTF-8 is unsupported in Mageia
- Upgrade to 1.4.2

* Sun May 07 2017 ngompa <ngompa> 1.4.1-1.mga6
+ Revision: 1099460
- Update to 1.4.1

* Thu Mar 16 2017 ngompa <ngompa> 1.3.5-1.mga6
+ Revision: 1093176
- Backport patch to add %%distro_section definition to Mageia configs
- Update to v1.3.5

* Tue Feb 21 2017 ngompa <ngompa> 1.3.2-2.mga6
+ Revision: 1087211
- Add mock-mageia-configs to be installed by default with mock

* Mon Nov 21 2016 ngompa <ngompa> 1.3.2-1.mga6
+ Revision: 1068551
- Update to v1.3.2

* Tue Sep 13 2016 ngompa <ngompa> 1.2.21-1.mga6
+ Revision: 1051975
- Upgrade to 1.2.21

* Mon Sep 05 2016 ngompa <ngompa> 1.2.20-1.mga6
+ Revision: 1050062
- Update to 1.2.20

* Fri Jun 10 2016 ngompa <ngompa> 1.2.18-1.mga6
+ Revision: 1021050
- Update to 1.2.18

* Fri Jun 03 2016 ngompa <ngompa> 1.2.17-6.mga6
+ Revision: 1020194
- Actually install Mageia configs

* Fri Jun 03 2016 ngompa <ngompa> 1.2.17-5.mga6
+ Revision: 1020081
- Replace python exec with sed to read mock arch in %%post

* Wed Jun 01 2016 ngompa <ngompa> 1.2.17-4.mga6
+ Revision: 1019726
- Fix %%post again by escaping %%distro_arch macro read

* Wed Jun 01 2016 ngompa <ngompa> 1.2.17-3.mga6
+ Revision: 1019662
- Fix %%post for setting default.cfg

* Mon May 30 2016 ngompa <ngompa> 1.2.17-2.mga6
+ Revision: 1019512
- * Use distro_arch macro for setting default build target config
  * Add patches to add Mageia targets to mock

* Tue Mar 15 2016 ngompa <ngompa> 1.2.17-1.mga6
+ Revision: 990752
- Update to 1.2.17

* Fri Feb 19 2016 umeabot <umeabot> 1.2.12-2.mga6
+ Revision: 970864
- Mageia 6 Mass Rebuild

* Sat Oct 10 2015 ovitters <ovitters> 1.2.12-1.mga6
+ Revision: 888714
- update filelist
- new version 1.2.12
- update source url
- new version 1.1.24

* Wed Oct 15 2014 umeabot <umeabot> 0.9.14-8.mga5
+ Revision: 744540
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.9.14-7.mga5
+ Revision: 682554
- Mageia 5 Mass Rebuild

  + pterjan <pterjan>
    - Rebuild for new Python

* Fri Oct 18 2013 umeabot <umeabot> 0.9.14-5.mga4
+ Revision: 507963
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 0.9.14-4.mga3
+ Revision: 360177
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jun 20 2011 dmorgan <dmorgan> 0.9.14-3.mga2
+ Revision: 110479
- imported package mock

